<?php

/**
 * Ermittelt Artikel-Status pro Sprache, bevor Artikel bzw. Kategorie gelscht wird,
 * da diese nach dem Lschen nicht mehr vorhanden sind (siehe EP 'ART_DELETED', 'CAT_DELETED')
 *
 * @param $params Parameter des EP 'ART_PRE_DELETED' (id Artikel-ID, ...)
 */
function mp_tags_structure_item_pre_deleted($params)
{
  global $REX;

  $id = $params['id'];

  $status = array();
  foreach ($REX['CLANG'] as $key => $val)
  {
    $art = OOArticle::getArticleById($id, $key);
    $status[$key] = $art->isOnline() ? 1 : 0;
  }

  $REX['ADDON']['mp_tags']['art_status_pre_delete'] = $status;

  return null;
}

/**
 * Lscht Tag-Artikel-Relation, wenn Artikel bzw. Kategorie gelscht wurde
 *
 * @param $params Parameter des EP 'ART_DELETED' (id Artikel-ID, clang Sprach-ID, status Status, ...)
 * @param $params Parameter des EP 'CAT_DELETED' (id Kategorie-ID, clang Sprach-ID, status Status, ...)
 */
function mp_tags_structure_item_deleted($params)
{
  global $REX;

  $debug = false;
  $id = $params['id'];

  $sel = rex_sql::factory();
  $sel->setDebug($debug);
  $sel->setQuery("SELECT `id`, `clang`, `rel_art_ids`
                  FROM `". $REX['TABLE_PREFIX']."mp_tags`
                  WHERE `rel_art_ids` LIKE '%|". $id ."|%'");
  if ($sel->getRows() > 0)
  {
    $upd = rex_sql::factory();
    $upd->setDebug($debug);

    // nur wenn gelschter Artikel "online" war, den Zhler um 1 erniedrigen
    $status = $REX['ADDON']['mp_tags']['art_status_pre_delete'];

    for ($i = 0; $i < $sel->getRows(); $i++)
    {
      $tag_id = $sel->getValue('id');
      $count_minus = $status[$sel->getValue('clang')];
      $articles = str_replace('|'.$id.'|', '|', $sel->getValue('rel_art_ids'));
      $upd->setQuery("UPDATE `". $REX['TABLE_PREFIX'] ."mp_tags`
                      SET `rel_art_ids` = '". $articles ."',
                          `rel_art_count` = `rel_art_count` - ".$count_minus."
                      WHERE `id` = ". $tag_id ." LIMIT 1");
      $sel->next();
    }

  }

  return null;
}

/**
 * Aktualisiert den Zhler fr Tag-Artikel-Relationen, wenn bei Artikel
 * bzw. Kategorie der Status verndert wurde
 *
 * @param $params Parameter des EP 'ART_STATUS' (id Artikel-ID, clang Sprach-ID, status Status)
 * @param $params Parameter des EP 'CAT_STATUS' (id Kategorie-ID, clang Sprach-ID, status Status)
 */
function mp_tags_structure_status_changed($params)
{
  global $REX;

  $debug = false;
  $id = $params['id'];
  $clang = $params['clang'];

  $upd = rex_sql::factory();
  $upd->setDebug($debug);

  if ($params['status'] == 1)
  {
    // neuer Status ist gleich 1 ( = online )
    // -> Artikel-Zhler um 1 erhhen
    $upd->setQuery("UPDATE `". $REX['TABLE_PREFIX'] ."mp_tags`
                    SET `rel_art_count` = `rel_art_count` + 1
                    WHERE `clang` = ". $clang ." 
                      AND `rel_art_ids` LIKE '%|". $id ."|%'");
  }
  elseif ($params['status'] == 0)
  {
    // neuer Status ist gleich 0 ( = offline )
    // -> Artikel-Zhler um 1 erniedrigen
    $upd->setQuery("UPDATE `". $REX['TABLE_PREFIX'] ."mp_tags`
                    SET `rel_art_count` = `rel_art_count` - 1
                    WHERE `clang` = ". $clang ." 
                      AND `rel_art_ids` LIKE '%|". $id ."|%'");
  }

  return null;
}

?>